==> fillets-ng-data-0.7.1.tar.gz: fillets-ng-data-0.7.1/script/corridor/dialogs_nl.lua <==

dialogId("ch-m-rozsvit0", "font_small", "Turn on the lights, NOW!")
dialogStr("Doe het licht aan! ONMIDDELIJK!")


dialogId("ch-m-rozsvit1", "font_small", "What do you think you are doing?")
dialogStr("Waar denk je dat je mee bezig bent?")


dialogId("ch-m-rozsvit2", "font_small", "Cut it out and turn on the lights.")
dialogStr("Hou daarmee op en doe het licht aan.")


dialogId("ch-v-pockej0", "font_big", "Wait, I`ll try to find the switch.")
dialogStr("Wacht, ik probeer de schakelaar te vinden.")


dialogId("ch-v-pockej1", "font_big", "I can`t. The dang switch fell down.")
dialogStr("Het lukt niet. De schakelaar is naar beneden gevallen.")


dialogId("ch-v-pockej2", "font_big", "Turn on the lights yourself, if you`re so smart.")
dialogStr("Doe het zelf, als jij alles zo goed weet.")


dialogId("ch-v-halo0", "font_big", "Where are you?")
dialogStr("Waar ben je?")


dialogId("ch-v-halo1", "font_big", "Hello-o-o.")
dialogStr("Haalloo.")


dialogId("ch-v-halo2", "font_big", "Say something.")
dialogStr("Zeg iets!")


dialogId("ch-m-tady0", "font_small", "Here.")
dialogStr("Hier.")


dialogId("ch-m-tady1", "font_small", "Here I am.")
dialogStr("Hierzo.")


dialogId("ch-m-tady2", "font_small", "I am right over here.")
dialogStr("Ik ben hier.")


dialogId("ch-m-bojim0", "font_small", "Where are you, I am afraid.")
dialogStr("Waar ben je? Dit is eng.")


dialogId("ch-m-bojim1", "font_small", "I`m afraid of the dark.")
dialogStr("Ik ben bang in het donker.")


dialogId("ch-m-bojim2", "font_small", "Please don`t leave. It`s so dark in here.")
dialogStr("laat me niet alleen. Het is hier zo donker.")


dialogId("ch-v-neboj0", "font_big", "Don`t be afraid. I`m here.")
dialogStr("Geen zorgen. Ik ben hier.")


dialogId("ch-v-neboj1", "font_big", "Stop whining. We`ll manage.")
dialogStr("Hou op met zeuren. Dit lossen we zo op.")


dialogId("ch-v-neboj2", "font_big", "There`s nothing to be afraid of.")
dialogStr("Wees niet bang.")


dialogId("ch-m-doufam", "font_small", "I hope it doesn`t kick me...")
dialogStr("Ik hoop dat ik geen klappen krijg...")


dialogId("ch-m-blik0", "font_small", "This flickering light is beginning to make my eyes hurt.")
dialogStr("Dit flikkerende licht doet pijn aan mijn ogen.")


dialogId("ch-m-blik1", "font_small", "I never thought I`d be so glad to see you again.")
dialogStr("Ik had niet gedacht dat ik ooit zo blij zou zijn om jou te zien.")


dialogId("ch-m-blik2", "font_small", "Finally, the lights are back on...")
dialogStr("Eindelijk is het licht weer aan...")


dialogId("ch-v-pozor", "font_big", "Be careful. It bites!")
dialogStr("Voorzichtig, hij bijt!")


dialogId("ch-v-robopes", "font_big", "Look! That must be... ROBODOG!")
dialogStr("Kijk nou! Dat is vast... ROBODOG!")


dialogId("ch-m-ten", "font_small", "What? THAT robodog?!?")
dialogStr("Wat? DAT is Robodog?!?")


dialogId("ch-v-zapada", "font_big", "Well now it all makes sense.")
dialogStr("Nu snap ik het!")


dialogId("ch-m-odpoved0", "font_small", "Including the Cuban missile crisis and Nostradamus` prophecies.")
dialogStr("Zelfs de Cubaanse raketcrisis en de profetieen van Nostradamus.")


dialogId("ch-m-odpoved1", "font_small", "Including the murder of John Lennon and the Tunguzian meteor.")
dialogStr("Zelfs de moord op John Lennon en de Tunguska-meteorietinslagen.")


dialogId("ch-m-odpoved2", "font_small", "Including the Challenger explosion and the Battle of Bull Run.")
dialogStr("Zelfs de Challenger-explosie en de slag bij Teutoburger Woud.")


dialogId("ch-m-odpoved3", "font_small", "Including the Chernobyl meltdown and the wreck of Noah`s Ark.")
dialogStr("Zelfs het ongeluk met Chernobyl en het wrak van de Ark van Noah.")


dialogId("ch-v-smysl", "font_big", "Now I can see the rationale behind this game.")
dialogStr("Nu begrijp ik het basisprincipe van dit spel.")


dialogId("ch-m-vubec", "font_small", "And also the meaning of life, the universe and everything.")
dialogStr("En ook de zin van het leven, het heelal en alles.")


dialogId("ch-x-click1", "font_darkgrey", "CLICK")
dialogStr("KLIK")


dialogId("ch-x-click2", "font_lightgrey", "CLICK")
dialogStr("KLIK")


dialogId("ch-r-nevsimej0", "font_robodog", "Don`t listen to them, player. They are kidding you.")
dialogStr("Let maar niet op hen, speler, ze maken een grapje.")


dialogId("ch-r-nevsimej1", "font_robodog", "Don`t listen to them, player. They are trying to be funny.")
dialogStr("Let maar niet op hen, speler, ze proberen je voor de gek te houden.")


dialogId("ch-r-nevsimej2", "font_robodog", "Don`t listen to them, player. They are trying to fool you.")
dialogStr("Let maar niet op hen, speler, ze zijn lollig aan het doen.")


dialogId("ch-r-hracka", "font_robodog", "I am but a humble cybernetic toy.")
dialogStr("Ik ben maar een nederig cybernetisch speledingetje.")


dialogId("ch-r-ikdyz0", "font_robodog", "Though originally I was to be a scooter.")
dialogStr("Hoewel ik oorspronkelijk een scooter had moeten worden.")


dialogId("ch-r-ikdyz1", "font_robodog", "Though originally I was to be a lawn-mower.")
dialogStr("Hoewel ik oorspronkelijk een grasmaaier had moeten worden.")


dialogId("ch-r-ikdyz2", "font_robodog", "Though originally I was to be a space orbital station.")
dialogStr("Hoewel ik oorspronkelijk een ruimtestation had moeten worden.")


dialogId("ch-r-ikdyz3", "font_robodog", "Though orginally I was to be a piece of cake.")
dialogStr("Hoewel ik oorspronkelijk een stukje taart had moeten worden.")


dialogId("ch-r-anavic0", "font_robodog", "And I visited Cuba only once.")
dialogStr("En ik ben maar één keer in Cuba geweest.")


dialogId("ch-r-anavic1", "font_robodog", "And everybody knows somebody else murdered him, they can`t prove anything.")
dialogStr("En iedereen weet dat iemand anders hem heeft vermoord. Ze hebben geen enkel bewijs.")


dialogId("ch-r-anavic2", "font_robodog", "And who cares about a few soldiers.")
dialogStr("En wat maken een soldaten nou uit.")


dialogId("ch-r-anavic3", "font_robodog", "And they told me that the regulatory rod wasn`t important.")
dialogStr("En ze zeiden dat die regelstaaf niet belangrijk was.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/corridor/dialogs_nl.lua <==

dialogId("ch-m-rozsvit0", "font_small", "Turn on the lights, NOW!")
dialogStr("Doe het licht aan! NU METEEN!")


dialogId("ch-m-rozsvit1", "font_small", "What do you think you are doing?")
dialogStr("Waar denk je dat je mee bezig bent?")


dialogId("ch-m-rozsvit2", "font_small", "Cut it out and turn on the lights.")
dialogStr("Hou daarmee op en doe het licht aan.")


dialogId("ch-v-pockej0", "font_big", "Wait, I’ll try to find the switch.")
dialogStr("Wacht, ik probeer de schakelaar te vinden.")


dialogId("ch-v-pockej1", "font_big", "I can’t. The dang switch fell down.")
dialogStr("Het lukt niet. Die verdraaide schakelaar is naar beneden gevallen.")


dialogId("ch-v-pockej2", "font_big", "Turn on the lights yourself, if you’re so smart.")
dialogStr("Doe het zelf, als jij alles zo goed weet.")


dialogId("ch-v-halo0", "font_big", "Where are you?")
dialogStr("Waar ben je?")


dialogId("ch-v-halo1", "font_big", "Hello-o-o.")
dialogStr("Haalloo.")


dialogId("ch-v-halo2", "font_big", "Say something.")
dialogStr("Zeg iets!")


dialogId("ch-m-tady0", "font_small", "Here.")
dialogStr("Hier.")


dialogId("ch-m-tady1", "font_small", "Here I am.")
dialogStr("Hierzo.")


dialogId("ch-m-tady2", "font_small", "I am right over here.")
dialogStr("Ik ben hier.")


dialogId("ch-m-bojim0", "font_small", "Where are you, I am afraid.")
dialogStr("Waar ben je? Dit is eng.")


dialogId("ch-m-bojim1", "font_small", "I’m afraid of the dark.")
dialogStr("Ik ben bang in het donker.")


dialogId("ch-m-bojim2", "font_small", "Please don’t leave. It’s so dark in here.")
dialogStr("Laat me niet alleen. Het is hier zo donker.")


dialogId("ch-v-neboj0", "font_big", "Don’t be afraid. I’m here.")
dialogStr("Wees niet bang. Ik ben hier.")


dialogId("ch-v-neboj1", "font_big", "Stop whining. We’ll manage.")
dialogStr("Hou op met zeuren. Dit lossen we zo op.")


dialogId("ch-v-neboj2", "font_big", "There’s nothing to be afraid of.")
dialogStr("Wees niet bang.")


dialogId("ch-m-doufam", "font_small", "I hope it doesn’t kick me...")
dialogStr("Ik hoop dat ik geen klappen krijg...")


dialogId("ch-m-blik0", "font_small", "This flickering light is beginning to make my eyes hurt.")
dialogStr("Dit flikkerende licht doet pijn aan mijn ogen.")


dialogId("ch-m-blik1", "font_small", "I never thought I’d be so glad to see you again.")
dialogStr("Ik had niet gedacht dat ik ooit zo blij zou zijn om jou te zien.")


dialogId("ch-m-blik2", "font_small", "Finally, the lights are back on...")
dialogStr("Eindelijk is het licht weer aan...")


dialogId("ch-v-pozor", "font_big", "Be careful. It bites!")
dialogStr("Voorzichtig, hij bijt!")


dialogId("ch-v-robopes", "font_big", "Look! That must be... ROBODOG!")
dialogStr("Kijk nou! Dat is vast... ROBOHOND!")


dialogId("ch-m-ten", "font_small", "What? THAT robodog?!?")
dialogStr("Wat? DE Robohond?!?")


dialogId("ch-v-zapada", "font_big", "Well now it all makes sense.")
dialogStr("Nu snap ik het!")


dialogId("ch-m-odpoved0", "font_small", "Including the Cuban missile crisis and Nostradamus’ prophecies.")
dialogStr("Zelfs de Cubaanse raketcrisis en de voorspellingen van Nostradamus.")


dialogId("ch-m-odpoved1", "font_small", "Including the murder of John Lennon and the Tunguzian meteor.")
dialogStr("Zelfs de moord op John Lennon en de Tunguska-meteorietinslagen.")


dialogId("ch-m-odpoved2", "font_small", "Including the Challenger explosion and the Battle of Bull Run.")
dialogStr("Zelfs de Challenger-explosie en de slag bij Teutoburger Woud.")


dialogId("ch-m-odpoved3", "font_small", "Including the Chernobyl meltdown and the wreck of Noah’s Ark.")
dialogStr("Zelfs het ongeluk met Chernobyl en het wrak van de Ark van Noah.")


dialogId("ch-v-smysl", "font_big", "Now I can see the rationale behind this game.")
dialogStr("Nu begrijp ik het basisprincipe van dit spel.")


dialogId("ch-m-vubec", "font_small", "And also the meaning of life, the universe and everything.")
dialogStr("En ook de zin van het leven, het heelal en alles.")


dialogId("ch-x-click1", "font_darkgrey", "CLICK")
dialogStr("KLIK")


dialogId("ch-x-click2", "font_lightgrey", "CLICK")
dialogStr("KLIK")


dialogId("ch-r-nevsimej0", "font_robodog", "Don’t listen to them, player. They are kidding you.")
dialogStr("Let maar niet op hen, speler, ze maken een grapje.")


dialogId("ch-r-nevsimej1", "font_robodog", "Don’t listen to them, player. They are trying to be funny.")
dialogStr("Let maar niet op hen, speler, ze proberen lollig te doen.")


dialogId("ch-r-nevsimej2", "font_robodog", "Don’t listen to them, player. They are trying to fool you.")
dialogStr("Let maar niet op hen, speler, ze proberen je voor de gek te houden.")


dialogId("ch-r-hracka", "font_robodog", "I am but a humble cybernetic toy.")
dialogStr("Ik ben maar een nederig cybernetisch speledingetje.")


dialogId("ch-r-ikdyz0", "font_robodog", "Though originally I was to be a scooter.")
dialogStr("Hoewel ik oorspronkelijk een scooter had moeten worden.")


dialogId("ch-r-ikdyz1", "font_robodog", "Though originally I was to be a lawn-mower.")
dialogStr("Hoewel ik oorspronkelijk een grasmaaier had moeten worden.")


dialogId("ch-r-ikdyz2", "font_robodog", "Though originally I was to be a space orbital station.")
dialogStr("Hoewel ik oorspronkelijk een ruimtestation had moeten worden.")


dialogId("ch-r-ikdyz3", "font_robodog", "Though orginally I was to be a piece of cake.")
dialogStr("Hoewel ik oorspronkelijk een stukje taart had moeten worden.")


dialogId("ch-r-anavic0", "font_robodog", "And I visited Cuba only once.")
dialogStr("En ik ben maar één keer in Cuba geweest.")


dialogId("ch-r-anavic1", "font_robodog", "And everybody knows somebody else murdered him, they can’t prove anything.")
dialogStr("En iedereen weet dat iemand anders hem heeft vermoord. Ze hebben geen enkel bewijs.")


dialogId("ch-r-anavic2", "font_robodog", "And who cares about a few soldiers.")
dialogStr("En wat maken een paar soldaten nou uit.")


dialogId("ch-r-anavic3", "font_robodog", "And they told me that the regulatory rod wasn’t important.")
dialogStr("En ze zeiden dat die regelstaaf niet belangrijk was.")
